#ifndef LIBJSONHANDLE_OPTIONS_H
#define LIBJSONHANDLE_OPTIONS_H

#include <expected>
#include <string>


class Options {

public:
    /**
     * std::string jsonText;
     * std::string query;
     */
    static std::expected<std::array<std::string, 4>, std::string>
    getOptions(int argc, char** argv);

};

#endif //LIBJSONHANDLE_OPTIONS_H